DiskSpacePlusPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DiskSpacePlusPlatform
Implementers

Constructors

DiskSpacePlusPlatform()
Constructs a DiskSpacePlusPlatform.

Properties

getFreeDiskSpace → Future<double?>
no setter
getTotalDiskSpace → Future<double?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFreeDiskSpaceForPath(String path) → Future<double?>
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ DiskSpacePlusPlatform
The default instance of DiskSpacePlusPlatform to use.
getter/setter pair